
History
=======


0.1.1 (2018-02-19)
------------------

* Fixed numpy dtype bug.
* Added first version of SLP data structure.
* Switched to MIT licence.
* Using tox-travis.
* Whitespace, formatting, Flake8.

0.1.0 (2017-12-11)
------------------

* First full release.

0.0.1 (2017-12-08)
------------------

* Test release on PyPI.
